@@ -29,20 +29,25 @@ describe 'manila' do
         )
         is_expected.to contain_oslo__messaging__notifications('manila_config').with(
           :transport_url => '<SERVICE DEFAULT>',
-          :driver        => 'messaging',
+          :driver        => '<SERVICE DEFAULT>',
           :topics        => '<SERVICE DEFAULT>',
+          :retry         => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__rabbit('manila_config').with(
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+          :heartbeat_rate                  => '<SERVICE DEFAULT>',
           :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
           :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_manila_config('DEFAULT/storage_availability_zone').with(
           :value => 'nova'
@@ -68,6 +73,9 @@ describe 'manila' do
         is_expected.to contain_manila_config('DEFAULT/periodic_fuzzy_delay').with(
           :value => '<SERVICE DEFAULT>'
         )
+        is_expected.to contain_manila_config('DEFAULT/service_down_time').with(
+          :value => '<SERVICE DEFAULT>'
+        )
         is_expected.to contain_oslo__concurrency('manila_config').with(
           :lock_path => platform_params[:lock_path]
         )
@@ -192,6 +200,9 @@ describe 'manila' do
           :rpc_response_timeout       => '120',
           :control_exchange           => 'manila',
           :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+          :notification_driver        => 'messagingv2',
+          :notification_topics        => ['notifications'],
+          :notification_retry         => 10,
           :executor_thread_pool_size  => 64,
         }
       end
@@ -204,31 +215,10 @@ describe 'manila' do
       ) }
 
       it { is_expected.to contain_oslo__messaging__notifications('manila_config').with(
-        :transport_url => 'rabbit://rabbit_user:password@localhost:5673'
-      ) }
-    end
-
-    context 'with amqp rpc supplied' do
-
-      let :params do
-        {}
-      end
-
-      it { is_expected.to contain_oslo__messaging__amqp('manila_config').with(
-          :server_request_prefix => '<SERVICE DEFAULT>',
-          :broadcast_prefix      => '<SERVICE DEFAULT>',
-          :group_request_prefix  => '<SERVICE DEFAULT>',
-          :container_name        => '<SERVICE DEFAULT>',
-          :idle_timeout          => '<SERVICE DEFAULT>',
-          :trace                 => '<SERVICE DEFAULT>',
-          :ssl_ca_file           => '<SERVICE DEFAULT>',
-          :ssl_cert_file         => '<SERVICE DEFAULT>',
-          :ssl_key_file          => '<SERVICE DEFAULT>',
-          :sasl_mechanisms       => '<SERVICE DEFAULT>',
-          :sasl_config_dir       => '<SERVICE DEFAULT>',
-          :sasl_config_name      => '<SERVICE DEFAULT>',
-          :username              => '<SERVICE DEFAULT>',
-          :password              => '<SERVICE DEFAULT>',
+        :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+        :driver        => 'messagingv2',
+        :topics        => ['notifications'],
+        :retry         => 10,
       ) }
     end
   end
