@@ -7,12 +7,15 @@ describe 'manila::backend::glusternfs' do
 
     let :params do
       {
-        :glusterfs_target              => 'remoteuser@volserver:volid',
-        :glusterfs_mount_point_base    => '$state_path/mnt',
-        :glusterfs_nfs_server_type     => 'gluster',
-        :glusterfs_path_to_private_key => '/etc/glusterfs/glusterfs.pem',
-        :glusterfs_ganesha_server_ip   => '127.0.0.1',
-        :backend_availability_zone     => 'my_zone',
+        :glusterfs_target                        => 'remoteuser@volserver:volid',
+        :glusterfs_mount_point_base              => '$state_path/mnt',
+        :glusterfs_nfs_server_type               => 'gluster',
+        :glusterfs_path_to_private_key           => '/etc/glusterfs/glusterfs.pem',
+        :glusterfs_ganesha_server_ip             => '127.0.0.1',
+        :backend_availability_zone               => 'my_zone',
+        :reserved_share_percentage               => 10.0,
+        :reserved_share_from_snapshot_percentage => 10.1,
+        :reserved_share_extend_percentage        => 10.2,
       }
     end
 
